Learn R Programming

EMGCR (version 0.2.0)

liver: Liver Cancer Data

Description

A sample of 2,766 patients diagnosed with liver cancer between 2012 and 2016, whose cancer grades were well identified. Available individual-level covariates include age at diagnosis, sex, pathological grade of the liver cancer, number of relapses, and median household income.

Usage

data(liver)

Arguments

Format

A data frame with 2,766 observations and 10 variables:

ID

Unique patient identifier

age

Age as a factor (e.g., age group)

ageNumeric

Age as a numeric variable

grade

Pathological grade of liver cancer (I, II, III, IV)

medh

Median household income as factor (possibly grouped)

medhNumeric

Median household income as numeric

relapse

Number of relapses after first diagnosis

sex

Sex of patient: 1 = male, 0 = female

status

Event indicator: 1 = death, 0 = censored

time

Survival time in months

Details

The grade of the disease is categorized into four levels:

  1. Grade I – Well differentiated

  2. Grade II – Moderately differentiated

  3. Grade III – Poorly differentiated

  4. Grade IV – Undifferentiated/anaplastic

Examples

Run this code
data(liver)
head(liver)

Run the code above in your browser using DataLab