Learn R Programming

EMGCR (version 0.2.0)

liver2: Liver Cancer Data 2

Description

A sample of 1,736 patients who have been diagnosed with liver cancer between 2012 and 2016, whose cancer grades are well identified. Available individual-level covariates include age at diagnosis, sex, race, grade of liver cancer, median household income, time to treatment, tumor size, radiation indicator, and chemotherapy indicator. The grade of diseas is categorized into four levels: well-differentiated (Grade I), moderately differentiated (Grade II), poorly differentiated (Grade III), and undifferentiated/anaplastic (Grade IV).

Usage

data(liver2)

Arguments

Format

A data frame with 1,736 observations and 10 variables:

ID

Unique patient identifier

time

Survival time in months

status

censored = 0, dead due to liver cancer = 1

sex

Sex of patient: Male=1, Female=0

age

Scaled age of diagnosis

medh

Scaled median household income of the subject

race

While = 1, Other = 0

grade

Pathological grade of liver cancer

chemo

chemotherapy = 1, non = 0

radio

radiation = 1, non = 0

Examples

Run this code
data(liver2)
head(liver2)

Run the code above in your browser using DataLab